(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{16:function(e,t,a){"use strict";a.r(t);var n=a(1),r=a.n(n),o=a(5),s=a.n(o),c=a(3),l=a(2),i=a.n(l),m=Object(c.b)((function(e){var t=e.args,a=t.locationLabel,o=t.showForecast,s=t.openWeatherObject,m=Object(l.useOpenWeather)(s),u=m.data,p=m.isLoading,g=m.errorMessage;return Object(n.useEffect)((function(){c.a.setFrameHeight()})),r.a.createElement(r.a.Fragment,null,console.log(e.args),r.a.createElement(i.a,{isLoading:p,errorMessage:g,data:u,lang:"en",locationLabel:a,unitsLabels:{temperature:"C",windSpeed:"Km/h"},showForecast:o}))}));s.a.render(r.a.createElement(r.a.StrictMode,null,r.a.createElement(m,null)),document.getElementById("root"))},7:function(e,t,a){e.exports=a(16)}},[[7,1,2]]]);
//# sourceMappingURL=main.ef090707.chunk.js.map